@@ -21,8 +21,9 @@
 
 #include "httplookup.h"
 
-#include <kio/job.h>
-#include <kdebug.h>
+#include <KIO/Job>
+#include <QtCore/QDebug>
+#include <QtCore/QUrlQuery>
 
 namespace KCDDB
 {
@@ -66,7 +67,7 @@ namespace KCDDB
     void
   HTTPLookup::initURL( const QString & hostName, uint port )
   {
-    cgiURL_.setProtocol( QLatin1String( "http" ) );
+    cgiURL_.setScheme( QLatin1String( "http" ) );
     cgiURL_.setHost( hostName );
     cgiURL_.setPort( port );
     cgiURL_.setPath( QLatin1String( "/~cddb/cddb.cgi" ) );
@@ -77,23 +78,22 @@ namespace KCDDB
     void
   HTTPLookup::makeURL( const QString & cmd )
   {
-    // The whole query has to constructed each time as the
-    // CDDB CGI script expects the parameters in strict order
-
-    cgiURL_.setQuery( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
-
     QString hello = QString::fromLatin1("%1 %2 %3 %4")
         .arg(user_, localHostName_, clientName(), clientVersion());
 
-    cgiURL_.addQueryItem( QLatin1String( "cmd" ), cmd );
-    cgiURL_.addQueryItem( QLatin1String( "hello" ), hello );
-    cgiURL_.addQueryItem( QLatin1String( "proto" ), QLatin1String( "6" ) );
+    // The whole query has to constructed each time as the
+    // CDDB CGI script expects the parameters in strict order
+    QUrlQuery query;
+    query.addQueryItem( QLatin1String( "cmd" ), cmd );
+    query.addQueryItem( QLatin1String( "hello" ), hello );
+    query.addQueryItem( QLatin1String( "proto" ), QLatin1String( "6" ) );
+    cgiURL_.setQuery( query );
   }
 
     void
   HTTPLookup::jobFinished()
   {
-    QStringList lineList = QString::fromUtf8(data_, data_.size()).split( QLatin1String( "\n" ), QString::SkipEmptyParts );
+    QStringList lineList = QString::fromUtf8(data_).split( QLatin1String( "\n" ), QString::SkipEmptyParts );
     QStringList::ConstIterator it = lineList.constBegin();
 
     switch ( state_ )
@@ -158,7 +158,7 @@ namespace KCDDB
         {
           CDInfo info;
 
-          if ( info.load( QString::fromUtf8(data_,data_.size()) ) )
+          if ( info.load( QString::fromUtf8(data_) ) )
           {
             info.set( QLatin1String( "category" ), category_ );
             info.set( QLatin1String( "discid" ), discid_ );
@@ -183,6 +183,4 @@ namespace KCDDB
   }
 }
 
-#include "httplookup.moc"
-
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
